function [residual, g1, g2, g3] = NKt_estYPIR_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(21, 1);
T23 = params(16)*y(11)^params(15);
T43 = params(1)*params(6)*y(28)^params(5);
T49 = y(28)^(params(5)-1);
T55 = y(6)/y(7)+params(1)*params(6)*T49/y(29)*y(31);
T62 = (params(4)/params(1))^(1-params(10));
T65 = T62*y(1)^params(10);
T70 = (y(9)/(steady_state(4)))^params(7);
T74 = (y(6)/(steady_state(1)))^params(8);
T75 = T70*T74;
T76 = T75^(1-params(10));
T95 = params(6)*y(9)^params(5);
T111 = params(2)^(1-params(9));
T114 = T111*y(3)^params(9);
T130 = params(3)^(1-params(11));
T133 = T130*y(4)^params(11);
lhs =1;
rhs =y(8)*params(1)*y(7)/y(27)/y(28);
residual(1)= lhs-rhs;
lhs =y(10);
rhs =y(7)*T23;
residual(2)= lhs-rhs;
lhs =y(14);
rhs =y(10)/y(17);
residual(3)= lhs-rhs;
lhs =params(5)*y(15);
rhs =(params(5)-1)*y(16);
residual(4)= lhs-rhs;
lhs =y(15);
rhs =y(14)*y(6)/y(7)+T43*y(30);
residual(5)= lhs-rhs;
lhs =y(16);
rhs =y(12)*T55;
residual(6)= lhs-rhs;
lhs =y(8);
rhs =T65*T76*y(19);
residual(7)= lhs-rhs;
lhs =y(18);
rhs =y(6)*y(20);
residual(8)= lhs-rhs;
lhs =1;
rhs =params(6)*y(9)^(params(5)-1)+(1-params(6))*y(12)^(1-params(5));
residual(9)= lhs-rhs;
lhs =y(13);
rhs =T95*y(2)+(1-params(6))*y(12)^(-params(5));
residual(10)= lhs-rhs;
lhs =y(6);
rhs =y(7)+y(18);
residual(11)= lhs-rhs;
lhs =y(6);
rhs =y(11)*y(17)/y(13);
residual(12)= lhs-rhs;
lhs =y(17);
rhs =T114*exp(params(13)*x(it_, 1));
residual(13)= lhs-rhs;
lhs =y(19);
rhs =exp((-params(14))*x(it_, 2));
residual(14)= lhs-rhs;
lhs =y(20);
rhs =T133*exp((-params(12))*x(it_, 3));
residual(15)= lhs-rhs;
lhs =y(21);
rhs =y(6)/(steady_state(1));
residual(16)= lhs-rhs;
lhs =y(22);
rhs =y(9)/(steady_state(4));
residual(17)= lhs-rhs;
lhs =y(23);
rhs =y(8)/(steady_state(3));
residual(18)= lhs-rhs;
lhs =y(24);
rhs =log(y(21))-log(y(5));
residual(19)= lhs-rhs;
lhs =y(25);
rhs =log(y(22));
residual(20)= lhs-rhs;
lhs =y(26);
rhs =log(y(23));
residual(21)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(21, 34);

  %
  % Jacobian matrix
  %

T170 = getPowerDeriv(T75,1-params(10),1);
  g1(1,7)=(-(y(8)*params(1)*1/y(27)/y(28)));
  g1(1,27)=(-(y(8)*params(1)*(-y(7))/(y(27)*y(27))/y(28)));
  g1(1,8)=(-(params(1)*y(7)/y(27)/y(28)));
  g1(1,28)=(-((-(y(8)*params(1)*y(7)/y(27)))/(y(28)*y(28))));
  g1(2,7)=(-T23);
  g1(2,10)=1;
  g1(2,11)=(-(y(7)*params(16)*getPowerDeriv(y(11),params(15),1)));
  g1(3,10)=(-(1/y(17)));
  g1(3,14)=1;
  g1(3,17)=(-((-y(10))/(y(17)*y(17))));
  g1(4,15)=params(5);
  g1(4,16)=(-(params(5)-1));
  g1(5,6)=(-(y(14)*1/y(7)));
  g1(5,7)=(-(y(14)*(-y(6))/(y(7)*y(7))));
  g1(5,28)=(-(y(30)*params(1)*params(6)*getPowerDeriv(y(28),params(5),1)));
  g1(5,14)=(-(y(6)/y(7)));
  g1(5,15)=1;
  g1(5,30)=(-T43);
  g1(6,6)=(-(y(12)*1/y(7)));
  g1(6,7)=(-(y(12)*(-y(6))/(y(7)*y(7))));
  g1(6,28)=(-(y(12)*y(31)*params(1)*params(6)*getPowerDeriv(y(28),params(5)-1,1)/y(29)));
  g1(6,12)=(-T55);
  g1(6,29)=(-(y(12)*y(31)*params(1)*params(6)*(-T49)/(y(29)*y(29))));
  g1(6,16)=1;
  g1(6,31)=(-(y(12)*params(1)*params(6)*T49/y(29)));
  g1(7,6)=(-(y(19)*T65*T70*1/(steady_state(1))*getPowerDeriv(y(6)/(steady_state(1)),params(8),1)*T170));
  g1(7,1)=(-(y(19)*T76*T62*getPowerDeriv(y(1),params(10),1)));
  g1(7,8)=1;
  g1(7,9)=(-(y(19)*T65*T170*T74*1/(steady_state(4))*getPowerDeriv(y(9)/(steady_state(4)),params(7),1)));
  g1(7,19)=(-(T65*T76));
  g1(8,6)=(-y(20));
  g1(8,18)=1;
  g1(8,20)=(-y(6));
  g1(9,9)=(-(params(6)*getPowerDeriv(y(9),params(5)-1,1)));
  g1(9,12)=(-((1-params(6))*getPowerDeriv(y(12),1-params(5),1)));
  g1(10,9)=(-(y(2)*params(6)*getPowerDeriv(y(9),params(5),1)));
  g1(10,12)=(-((1-params(6))*getPowerDeriv(y(12),(-params(5)),1)));
  g1(10,2)=(-T95);
  g1(10,13)=1;
  g1(11,6)=1;
  g1(11,7)=(-1);
  g1(11,18)=(-1);
  g1(12,6)=1;
  g1(12,11)=(-(y(17)/y(13)));
  g1(12,13)=(-(y(11)*(-y(17))/(y(13)*y(13))));
  g1(12,17)=(-(y(11)*1/y(13)));
  g1(13,3)=(-(exp(params(13)*x(it_, 1))*T111*getPowerDeriv(y(3),params(9),1)));
  g1(13,17)=1;
  g1(13,32)=(-(T114*params(13)*exp(params(13)*x(it_, 1))));
  g1(14,19)=1;
  g1(14,33)=(-((-params(14))*exp((-params(14))*x(it_, 2))));
  g1(15,4)=(-(exp((-params(12))*x(it_, 3))*T130*getPowerDeriv(y(4),params(11),1)));
  g1(15,20)=1;
  g1(15,34)=(-(T133*(-params(12))*exp((-params(12))*x(it_, 3))));
  g1(16,6)=(-(1/(steady_state(1))));
  g1(16,21)=1;
  g1(17,9)=(-(1/(steady_state(4))));
  g1(17,22)=1;
  g1(18,8)=(-(1/(steady_state(3))));
  g1(18,23)=1;
  g1(19,5)=1/y(5);
  g1(19,21)=(-(1/y(21)));
  g1(19,24)=1;
  g1(20,22)=(-(1/y(22)));
  g1(20,25)=1;
  g1(21,23)=(-(1/y(23)));
  g1(21,26)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],21,1156);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],21,39304);
end
end
end
end
