function [residual, g1, g2, g3] = NKt_estYPIR_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 21, 1);

%
% Model equations
%

T20 = params(16)*y(6)^params(15);
T39 = y(4)^params(5);
T45 = y(4)^(params(5)-1);
T49 = y(1)/y(2)+y(11)*params(1)*params(6)*T45/y(7);
T56 = (params(4)/params(1))^(1-params(10));
T58 = T56*y(3)^params(10);
T62 = (y(4)/(y(4)))^params(7);
T66 = (y(1)/(y(1)))^params(8);
T67 = T62*T66;
T68 = T67^(1-params(10));
T100 = params(2)^(1-params(9));
T118 = params(3)^(1-params(11));
lhs =1;
rhs =y(3)*params(1)/y(4);
residual(1)= lhs-rhs;
lhs =y(5);
rhs =y(2)*T20;
residual(2)= lhs-rhs;
lhs =y(9);
rhs =y(5)/y(12);
residual(3)= lhs-rhs;
lhs =params(5)*y(10);
rhs =(params(5)-1)*y(11);
residual(4)= lhs-rhs;
lhs =y(10);
rhs =y(9)*y(1)/y(2)+y(10)*params(1)*params(6)*T39;
residual(5)= lhs-rhs;
lhs =y(11);
rhs =y(7)*T49;
residual(6)= lhs-rhs;
lhs =y(3);
rhs =T58*T68*y(14);
residual(7)= lhs-rhs;
lhs =y(13);
rhs =y(1)*y(15);
residual(8)= lhs-rhs;
lhs =1;
rhs =params(6)*T45+(1-params(6))*y(7)^(1-params(5));
residual(9)= lhs-rhs;
lhs =y(8);
rhs =y(8)*params(6)*T39+(1-params(6))*y(7)^(-params(5));
residual(10)= lhs-rhs;
lhs =y(1);
rhs =y(2)+y(13);
residual(11)= lhs-rhs;
lhs =y(1);
rhs =y(6)*y(12)/y(8);
residual(12)= lhs-rhs;
lhs =y(12);
rhs =T100*y(12)^params(9)*exp(params(13)*x(1));
residual(13)= lhs-rhs;
lhs =y(14);
rhs =exp((-params(14))*x(2));
residual(14)= lhs-rhs;
lhs =y(15);
rhs =T118*y(15)^params(11)*exp((-params(12))*x(3));
residual(15)= lhs-rhs;
lhs =y(16);
rhs =y(1)/(y(1));
residual(16)= lhs-rhs;
lhs =y(17);
rhs =y(4)/(y(4));
residual(17)= lhs-rhs;
lhs =y(18);
rhs =y(3)/(y(3));
residual(18)= lhs-rhs;
residual(19) = y(19);
lhs =y(20);
rhs =log(y(17));
residual(20)= lhs-rhs;
lhs =y(21);
rhs =log(y(18));
residual(21)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(21, 21);

  %
  % Jacobian matrix
  %

T156 = getPowerDeriv(T67,1-params(10),1);
T186 = getPowerDeriv(y(4),params(5),1);
T190 = getPowerDeriv(y(4),params(5)-1,1);
  g1(1,3)=(-(params(1)/y(4)));
  g1(1,4)=(-((-(y(3)*params(1)))/(y(4)*y(4))));
  g1(2,2)=(-T20);
  g1(2,5)=1;
  g1(2,6)=(-(y(2)*params(16)*getPowerDeriv(y(6),params(15),1)));
  g1(3,5)=(-(1/y(12)));
  g1(3,9)=1;
  g1(3,12)=(-((-y(5))/(y(12)*y(12))));
  g1(4,10)=params(5);
  g1(4,11)=(-(params(5)-1));
  g1(5,1)=(-(y(9)*1/y(2)));
  g1(5,2)=(-(y(9)*(-y(1))/(y(2)*y(2))));
  g1(5,4)=(-(y(10)*params(1)*params(6)*T186));
  g1(5,9)=(-(y(1)/y(2)));
  g1(5,10)=1-params(1)*params(6)*T39;
  g1(6,1)=(-(y(7)*1/y(2)));
  g1(6,2)=(-(y(7)*(-y(1))/(y(2)*y(2))));
  g1(6,4)=(-(y(7)*y(11)*params(1)*params(6)*T190/y(7)));
  g1(6,7)=(-(T49+y(7)*y(11)*params(1)*params(6)*(-T45)/(y(7)*y(7))));
  g1(6,11)=1-y(7)*params(1)*params(6)*T45/y(7);
  g1(7,1)=(-(y(14)*T58*T62*((y(1))-y(1))/((y(1))*(y(1)))*getPowerDeriv(y(1)/(y(1)),params(8),1)*T156));
  g1(7,3)=1-y(14)*T68*T56*getPowerDeriv(y(3),params(10),1);
  g1(7,4)=(-(y(14)*T58*T156*T66*((y(4))-y(4))/((y(4))*(y(4)))*getPowerDeriv(y(4)/(y(4)),params(7),1)));
  g1(7,14)=(-(T58*T68));
  g1(8,1)=(-y(15));
  g1(8,13)=1;
  g1(8,15)=(-y(1));
  g1(9,4)=(-(params(6)*T190));
  g1(9,7)=(-((1-params(6))*getPowerDeriv(y(7),1-params(5),1)));
  g1(10,4)=(-(y(8)*params(6)*T186));
  g1(10,7)=(-((1-params(6))*getPowerDeriv(y(7),(-params(5)),1)));
  g1(10,8)=1-params(6)*T39;
  g1(11,1)=1;
  g1(11,2)=(-1);
  g1(11,13)=(-1);
  g1(12,1)=1;
  g1(12,6)=(-(y(12)/y(8)));
  g1(12,8)=(-(y(6)*(-y(12))/(y(8)*y(8))));
  g1(12,12)=(-(y(6)*1/y(8)));
  g1(13,12)=1-exp(params(13)*x(1))*T100*getPowerDeriv(y(12),params(9),1);
  g1(14,14)=1;
  g1(15,15)=1-exp((-params(12))*x(3))*T118*getPowerDeriv(y(15),params(11),1);
  g1(16,1)=(-(((y(1))-y(1))/((y(1))*(y(1)))));
  g1(16,16)=1;
  g1(17,4)=(-(((y(4))-y(4))/((y(4))*(y(4)))));
  g1(17,17)=1;
  g1(18,3)=(-(((y(3))-y(3))/((y(3))*(y(3)))));
  g1(18,18)=1;
  g1(19,19)=1;
  g1(20,17)=(-(1/y(17)));
  g1(20,20)=1;
  g1(21,18)=(-(1/y(18)));
  g1(21,21)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],21,441);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],21,9261);
end
end
end
end
