
@#define linear = 0
% 1 linear estimation 
% 0 non-linear

var Y, C, R, PI, W, L, PI_STAR, NU, MC, AUX1, AUX2, A, G, M, Sg, YY, PIPI, RR;
varexo epsilon_a, epsilon_m, epsilon_g;

parameters beta, A_STEADY, Sg_STEADY, PI_STEADY, varepsilon, theta, phi_pi, phi_y, rho_a, rho_r, rho_g, sigma_g, sigma_a, sigma_m, vartheta, psi;

beta = 0.99;
Sg_STEADY = 0.2;
A_STEADY = 1;
PI_STEADY = 1.005;
psi = 2;
vartheta = 1;
theta = 0.75;
varepsilon = 6;
phi_pi = 1.5;
phi_y = 0.25;
rho_r = 0;
rho_a = 0.9;
rho_g = 0.8;
sigma_a = 0.1;%0025;
sigma_m = 0.1;%0025;
sigma_g = 0.1;%0032;


var dy_star, pinfobs_star robs_star;
varobs dy_star, pinfobs_star robs_star;


model;
	1 = R * beta * ( C / C(+1) ) / PI(+1);
	W = psi * L^vartheta*C;
	MC = W/A;
	varepsilon * AUX1 = (varepsilon - 1) * AUX2;
	AUX1 = MC * (Y/C) + theta * beta * PI(+1)^(varepsilon) * AUX1(+1);
	AUX2 = PI_STAR * ((Y/C) + theta * beta * ((PI(+1)^(varepsilon-1))/PI_STAR(+1)) * AUX2(+1));
	R =(PI_STEADY / beta )^(1 - rho_r) * R(-1)^rho_r * ( ((PI/STEADY_STATE(PI))^phi_pi) * ((Y/STEADY_STATE(Y))^phi_y) )^(1 - rho_r) * M;
	G = Sg*Y;
	1 = theta * (PI^(varepsilon-1)) + (1 - theta) * PI_STAR^(1 - varepsilon);
	NU = theta * (PI^varepsilon) * NU(-1) + (1 - theta) * PI_STAR^(-varepsilon);
	Y = C + G;
	Y = (A/NU) * L;	
	
	A = A_STEADY^(1 - rho_a) * A(-1) ^(rho_a) * exp(sigma_a * epsilon_a);
	M = exp(-sigma_m * epsilon_m);
	Sg = Sg_STEADY^(1 - rho_g) * Sg(-1)^rho_g * exp(-sigma_g*epsilon_g);

    YY=Y/STEADY_STATE(Y);
    PIPI=PI/STEADY_STATE(PI);
    RR=R/STEADY_STATE(R);

    dy_star= LOG(YY)-LOG(YY(-1));
    pinfobs_star=LOG(PIPI);
    robs_star=LOG(RR)         ;
 end;

steady_state_model;
A = A_STEADY;
Sg = Sg_STEADY;
M = 1;
PI = PI_STEADY;
PI_STAR = ( (1 - theta * (1 / PI)^(1 - varepsilon) ) / (1 - theta) )^(1/(1 - varepsilon));
NU = ( ( 1 - theta) / (1 - theta * PI ^varepsilon) ) * PI_STAR ^(-varepsilon);
W = A_STEADY * PI_STAR * ((varepsilon - 1) / varepsilon) * ( (1 - theta * beta * PI ^varepsilon)/(1 - theta * beta * PI ^(varepsilon-1)));
C = (W /(psi * ((1/(1 - Sg)) * NU/ A_STEADY)^vartheta))^(1/(1 + vartheta));
Y = (1 / (1 - Sg)) * C;
G = Sg * Y;
L = Y *NU / A_STEADY;
MC = W / A_STEADY;
R = PI / beta;
AUX1 = W / A_STEADY * (Y /C)/(1 - theta * beta * PI ^varepsilon);
AUX2 = PI_STAR * (Y /C)/(1 - theta * beta * PI ^(varepsilon-1));

    YY=1;
    PIPI=1;
    RR=1;
    
    dy_star=0;
    pinfobs_star=LOG(PIPI);
    robs_star=LOG(RR)  ;
end;

shocks;
	var epsilon_a = 1;
	var epsilon_g = 1;
	var epsilon_m = 1;
end;

steady;
check;
options_.debug=1;
model_diagnostics;


 estimated_params;
 // PARAM NAME, INITVAL, LB, UB, PRIOR_SHAPE, PRIOR_P1, PRIOR_P2, PRIOR_P3, PRIOR_P4, JSCALE (JSCALE for a single parameter, needs P3 and P4)
 // PRIOR_SHAPE: BETA_PDF, GAMMA_PDF, NORMAL_PDF, INV_GAMMA_PDF
 //
 % -------------------------------------------------------------------------------------------------------------------------------------------------------------------
 %PARAMETER_NAME, INITIAL_VALUE, LOWER_BOUND, UPPER_BOUND, PRIOR_SHAPE,   PRIOR_MEAN, PRIOR_STANDARD_ERROR, PRIOR_3RD_PARAMETER, PRIOR_4TH_PARAMETER, SCALE_PARAMETER;
 % -------------------------------------------------------------------------------------------------------------------------------------------------------------------
% beta, 					   beta,        0.97,       0.999, 	 BETA_PDF ,        beta ,                 0.03,					   , 					;
 Sg_STEADY,  		  Sg_STEADY,      0.0001,      0.9999, 	 BETA_PDF ,   Sg_STEADY ,                 0.10,					   ,    	    		;											
 A_STEADY ,            A_STEADY,      0.0001,         inf,  GAMMA_PDF ,    A_STEADY ,                 0.10, 				   ,	    			;
 %PI_STEADY, 			  1.005, 		   0, theta^(1/(1-varepsilon)), GAMMA_PDF , 1  ,              0.10, 				   ,		     		 ;
 psi,                      psi ,      0.0001,         Inf, 	GAMMA_PDF ,         psi ,                 0.10, 				   ,                    ;
 varepsilon,		varepsilon , 	  1.0001,         Inf,  GAMMA_PDF ,  varepsilon ,                 0.10, 				   ,				 ;
 theta, 				   theta, 		 0.5,		    1,   BETA_PDF ,	      theta , 				  0.10,					   , 			   	 ;
 phi_pi, 				  phi_pi, 		   1, 		  Inf, 	GAMMA_PDF ,      phi_pi ,                 0.10, 				   ,				 ;
 phi_y,                   phi_y ,     0.0001,         Inf, 	GAMMA_PDF ,       phi_y ,                 0.10, 				   ,				 ;
 rho_a, 				   rho_a, 	  0.0001,      0.9999,   BETA_PDF ,	      rho_a , 				  0.05, 				   , 			   	 ; 
 rho_g, 				   rho_g, 	  0.0001,      0.9999,   BETA_PDF ,	      rho_g , 				  0.05, 				   , 			   	 ;
 sigma_g, 				 sigma_g, 	  0.0001,		  Inf, 	GAMMA_PDF ,     sigma_g ,                 0.05, 				   ,				 ;
 sigma_a,				 sigma_a, 	  0.0001, 		  Inf, 	GAMMA_PDF ,     sigma_a ,                 0.05, 				   ,				 ;
 sigma_m, 				 sigma_m, 	  0.0001, 		  Inf, 	GAMMA_PDF ,     sigma_m ,                 0.05, 				   ,				 ;
 vartheta, 				vartheta, 	  0.0001, 		  Inf, 	GAMMA_PDF ,    vartheta ,                 0.10, 				   ,				 ;

% Measurement errors
    stderr dy_star,           0.1,         0.001,     inf,	INV_GAMMA_PDF,       0.10,                 5.00; 
    stderr pinfobs_star, 	  0.1,         0.001,     inf,  INV_GAMMA_PDF,       0.10,                 5.00; 
    stderr robs_star,         0.1,         0.001,     inf,  INV_GAMMA_PDF,       0.10,                 5.00;
 end;
       
 %estimated_params_init(use_calibration);
 %end;

@#if linear == 1 
estimation(datafile='us_data',order=1, mode_compute=8, mh_replic=10000, mode_check) dy_star, pinfobs_star robs_star;
@#else
estimation(datafile='us_data',order=2, 
filter_algorithm=nlkf,proposal_approximation=cubature, distribution_approximation=cubature,
mode_compute=8, mh_replic=0
, mode_check, graph_format=fig)  dy_star, pinfobs_star robs_star;
@#endif

