function [residual, g1, g2, g3] = NKt_estYPIR_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(21, 1);
T23 = params(16)*y(11)^params(15);
T43 = params(1)*params(6)*y(28)^params(5);
T49 = y(28)^(params(5)-1);
T55 = y(6)/y(7)+params(1)*params(6)*T49/y(29)*y(31);
T62 = (params(4)/params(1))^(1-params(10));
T65 = T62*y(1)^params(10);
T68 = y(9)/(steady_state(4));
T70 = T68^params(7);
T72 = y(6)/(steady_state(1));
T74 = T72^params(8);
T75 = T70*T74;
T76 = T75^(1-params(10));
T95 = params(6)*y(9)^params(5);
T111 = params(2)^(1-params(9));
T114 = T111*y(3)^params(9);
T130 = params(3)^(1-params(11));
T133 = T130*y(4)^params(11);
lhs =1;
rhs =y(8)*params(1)*y(7)/y(27)/y(28);
residual(1)= lhs-rhs;
lhs =y(10);
rhs =y(7)*T23;
residual(2)= lhs-rhs;
lhs =y(14);
rhs =y(10)/y(17);
residual(3)= lhs-rhs;
lhs =params(5)*y(15);
rhs =(params(5)-1)*y(16);
residual(4)= lhs-rhs;
lhs =y(15);
rhs =y(14)*y(6)/y(7)+T43*y(30);
residual(5)= lhs-rhs;
lhs =y(16);
rhs =y(12)*T55;
residual(6)= lhs-rhs;
lhs =y(8);
rhs =T65*T76*y(19);
residual(7)= lhs-rhs;
lhs =y(18);
rhs =y(6)*y(20);
residual(8)= lhs-rhs;
lhs =1;
rhs =params(6)*y(9)^(params(5)-1)+(1-params(6))*y(12)^(1-params(5));
residual(9)= lhs-rhs;
lhs =y(13);
rhs =T95*y(2)+(1-params(6))*y(12)^(-params(5));
residual(10)= lhs-rhs;
lhs =y(6);
rhs =y(7)+y(18);
residual(11)= lhs-rhs;
lhs =y(6);
rhs =y(11)*y(17)/y(13);
residual(12)= lhs-rhs;
lhs =y(17);
rhs =T114*exp(params(13)*x(it_, 1));
residual(13)= lhs-rhs;
lhs =y(19);
rhs =exp((-params(14))*x(it_, 2));
residual(14)= lhs-rhs;
lhs =y(20);
rhs =T133*exp((-params(12))*x(it_, 3));
residual(15)= lhs-rhs;
lhs =y(21);
rhs =T72;
residual(16)= lhs-rhs;
lhs =y(22);
rhs =T68;
residual(17)= lhs-rhs;
lhs =y(23);
rhs =y(8)/(steady_state(3));
residual(18)= lhs-rhs;
lhs =y(24);
rhs =log(y(21))-log(y(5));
residual(19)= lhs-rhs;
lhs =y(25);
rhs =log(y(22));
residual(20)= lhs-rhs;
lhs =y(26);
rhs =log(y(23));
residual(21)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(21, 34);

  %
  % Jacobian matrix
  %

T166 = 1/(steady_state(1));
T168 = T166*getPowerDeriv(T72,params(8),1);
T169 = T70*T168;
T170 = getPowerDeriv(T75,1-params(10),1);
T196 = T62*getPowerDeriv(y(1),params(10),1);
T205 = 1/(steady_state(4));
T207 = T205*getPowerDeriv(T68,params(7),1);
T208 = T74*T207;
T217 = params(6)*getPowerDeriv(y(9),params(5),1);
T226 = params(1)*params(6)*getPowerDeriv(y(28),params(5),1);
T229 = getPowerDeriv(y(28),params(5)-1,1);
T232 = y(31)*params(1)*params(6)*T229/y(29);
T238 = params(16)*getPowerDeriv(y(11),params(15),1);
T268 = T111*getPowerDeriv(y(3),params(9),1);
T280 = T130*getPowerDeriv(y(4),params(11),1);
  g1(1,7)=(-(y(8)*params(1)*1/y(27)/y(28)));
  g1(1,27)=(-(y(8)*params(1)*(-y(7))/(y(27)*y(27))/y(28)));
  g1(1,8)=(-(params(1)*y(7)/y(27)/y(28)));
  g1(1,28)=(-((-(y(8)*params(1)*y(7)/y(27)))/(y(28)*y(28))));
  g1(2,7)=(-T23);
  g1(2,10)=1;
  g1(2,11)=(-(y(7)*T238));
  g1(3,10)=(-(1/y(17)));
  g1(3,14)=1;
  g1(3,17)=(-((-y(10))/(y(17)*y(17))));
  g1(4,15)=params(5);
  g1(4,16)=(-(params(5)-1));
  g1(5,6)=(-(y(14)*1/y(7)));
  g1(5,7)=(-(y(14)*(-y(6))/(y(7)*y(7))));
  g1(5,28)=(-(y(30)*T226));
  g1(5,14)=(-(y(6)/y(7)));
  g1(5,15)=1;
  g1(5,30)=(-T43);
  g1(6,6)=(-(y(12)*1/y(7)));
  g1(6,7)=(-(y(12)*(-y(6))/(y(7)*y(7))));
  g1(6,28)=(-(y(12)*T232));
  g1(6,12)=(-T55);
  g1(6,29)=(-(y(12)*y(31)*params(1)*params(6)*(-T49)/(y(29)*y(29))));
  g1(6,16)=1;
  g1(6,31)=(-(y(12)*params(1)*params(6)*T49/y(29)));
  g1(7,6)=(-(y(19)*T65*T169*T170));
  g1(7,1)=(-(y(19)*T76*T196));
  g1(7,8)=1;
  g1(7,9)=(-(y(19)*T65*T170*T208));
  g1(7,19)=(-(T65*T76));
  g1(8,6)=(-y(20));
  g1(8,18)=1;
  g1(8,20)=(-y(6));
  g1(9,9)=(-(params(6)*getPowerDeriv(y(9),params(5)-1,1)));
  g1(9,12)=(-((1-params(6))*getPowerDeriv(y(12),1-params(5),1)));
  g1(10,9)=(-(y(2)*T217));
  g1(10,12)=(-((1-params(6))*getPowerDeriv(y(12),(-params(5)),1)));
  g1(10,2)=(-T95);
  g1(10,13)=1;
  g1(11,6)=1;
  g1(11,7)=(-1);
  g1(11,18)=(-1);
  g1(12,6)=1;
  g1(12,11)=(-(y(17)/y(13)));
  g1(12,13)=(-(y(11)*(-y(17))/(y(13)*y(13))));
  g1(12,17)=(-(y(11)*1/y(13)));
  g1(13,3)=(-(exp(params(13)*x(it_, 1))*T268));
  g1(13,17)=1;
  g1(13,32)=(-(T114*params(13)*exp(params(13)*x(it_, 1))));
  g1(14,19)=1;
  g1(14,33)=(-((-params(14))*exp((-params(14))*x(it_, 2))));
  g1(15,4)=(-(exp((-params(12))*x(it_, 3))*T280));
  g1(15,20)=1;
  g1(15,34)=(-(T133*(-params(12))*exp((-params(12))*x(it_, 3))));
  g1(16,6)=(-T166);
  g1(16,21)=1;
  g1(17,9)=(-T205);
  g1(17,22)=1;
  g1(18,8)=(-(1/(steady_state(3))));
  g1(18,23)=1;
  g1(19,5)=1/y(5);
  g1(19,21)=(-(1/y(21)));
  g1(19,24)=1;
  g1(20,22)=(-(1/y(22)));
  g1(20,25)=1;
  g1(21,23)=(-(1/y(23)));
  g1(21,26)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(94,3);
T398 = getPowerDeriv(T75,1-params(10),2);
T399 = T169*T398;
  v2(1,1)=1;
  v2(1,2)=891;
  v2(1,3)=(-(y(8)*params(1)*(-1)/(y(27)*y(27))/y(28)));
  v2(2,1)=1;
  v2(2,2)=231;
  v2(2,3)=  v2(1,3);
  v2(3,1)=1;
  v2(3,2)=911;
  v2(3,3)=(-(y(8)*params(1)*(-((-y(7))*(y(27)+y(27))))/(y(27)*y(27)*y(27)*y(27))/y(28)));
  v2(4,1)=1;
  v2(4,2)=245;
  v2(4,3)=(-(params(1)*1/y(27)/y(28)));
  v2(5,1)=1;
  v2(5,2)=212;
  v2(5,3)=  v2(4,3);
  v2(6,1)=1;
  v2(6,2)=265;
  v2(6,3)=(-(params(1)*(-y(7))/(y(27)*y(27))/y(28)));
  v2(7,1)=1;
  v2(7,2)=892;
  v2(7,3)=  v2(6,3);
  v2(8,1)=1;
  v2(8,2)=925;
  v2(8,3)=(-((-(y(8)*params(1)*1/y(27)))/(y(28)*y(28))));
  v2(9,1)=1;
  v2(9,2)=232;
  v2(9,3)=  v2(8,3);
  v2(10,1)=1;
  v2(10,2)=945;
  v2(10,3)=(-((-(y(8)*params(1)*(-y(7))/(y(27)*y(27))))/(y(28)*y(28))));
  v2(11,1)=1;
  v2(11,2)=912;
  v2(11,3)=  v2(10,3);
  v2(12,1)=1;
  v2(12,2)=926;
  v2(12,3)=(-((-(params(1)*y(7)/y(27)))/(y(28)*y(28))));
  v2(13,1)=1;
  v2(13,2)=266;
  v2(13,3)=  v2(12,3);
  v2(14,1)=1;
  v2(14,2)=946;
  v2(14,3)=(-((-((-(y(8)*params(1)*y(7)/y(27)))*(y(28)+y(28))))/(y(28)*y(28)*y(28)*y(28))));
  v2(15,1)=2;
  v2(15,2)=347;
  v2(15,3)=(-T238);
  v2(16,1)=2;
  v2(16,2)=215;
  v2(16,3)=  v2(15,3);
  v2(17,1)=2;
  v2(17,2)=351;
  v2(17,3)=(-(y(7)*params(16)*getPowerDeriv(y(11),params(15),2)));
  v2(18,1)=3;
  v2(18,2)=554;
  v2(18,3)=(-((-1)/(y(17)*y(17))));
  v2(19,1)=3;
  v2(19,2)=323;
  v2(19,3)=  v2(18,3);
  v2(20,1)=3;
  v2(20,2)=561;
  v2(20,3)=(-((-((-y(10))*(y(17)+y(17))))/(y(17)*y(17)*y(17)*y(17))));
  v2(21,1)=5;
  v2(21,2)=210;
  v2(21,3)=(-(y(14)*(-1)/(y(7)*y(7))));
  v2(22,1)=5;
  v2(22,2)=177;
  v2(22,3)=  v2(21,3);
  v2(23,1)=5;
  v2(23,2)=211;
  v2(23,3)=(-(y(14)*(-((-y(6))*(y(7)+y(7))))/(y(7)*y(7)*y(7)*y(7))));
  v2(24,1)=5;
  v2(24,2)=946;
  v2(24,3)=(-(y(30)*params(1)*params(6)*getPowerDeriv(y(28),params(5),2)));
  v2(25,1)=5;
  v2(25,2)=448;
  v2(25,3)=(-(1/y(7)));
  v2(26,1)=5;
  v2(26,2)=184;
  v2(26,3)=  v2(25,3);
  v2(27,1)=5;
  v2(27,2)=449;
  v2(27,3)=(-((-y(6))/(y(7)*y(7))));
  v2(28,1)=5;
  v2(28,2)=218;
  v2(28,3)=  v2(27,3);
  v2(29,1)=5;
  v2(29,2)=1014;
  v2(29,3)=(-T226);
  v2(30,1)=5;
  v2(30,2)=948;
  v2(30,3)=  v2(29,3);
  v2(31,1)=6;
  v2(31,2)=210;
  v2(31,3)=(-(y(12)*(-1)/(y(7)*y(7))));
  v2(32,1)=6;
  v2(32,2)=177;
  v2(32,3)=  v2(31,3);
  v2(33,1)=6;
  v2(33,2)=211;
  v2(33,3)=(-(y(12)*(-((-y(6))*(y(7)+y(7))))/(y(7)*y(7)*y(7)*y(7))));
  v2(34,1)=6;
  v2(34,2)=946;
  v2(34,3)=(-(y(12)*y(31)*params(1)*params(6)*getPowerDeriv(y(28),params(5)-1,2)/y(29)));
  v2(35,1)=6;
  v2(35,2)=380;
  v2(35,3)=(-(1/y(7)));
  v2(36,1)=6;
  v2(36,2)=182;
  v2(36,3)=  v2(35,3);
  v2(37,1)=6;
  v2(37,2)=381;
  v2(37,3)=(-((-y(6))/(y(7)*y(7))));
  v2(38,1)=6;
  v2(38,2)=216;
  v2(38,3)=  v2(37,3);
  v2(39,1)=6;
  v2(39,2)=402;
  v2(39,3)=(-T232);
  v2(40,1)=6;
  v2(40,2)=930;
  v2(40,3)=  v2(39,3);
  v2(41,1)=6;
  v2(41,2)=980;
  v2(41,3)=(-(y(12)*y(31)*params(1)*params(6)*(-T229)/(y(29)*y(29))));
  v2(42,1)=6;
  v2(42,2)=947;
  v2(42,3)=  v2(41,3);
  v2(43,1)=6;
  v2(43,2)=964;
  v2(43,3)=(-(y(31)*params(1)*params(6)*(-T49)/(y(29)*y(29))));
  v2(44,1)=6;
  v2(44,2)=403;
  v2(44,3)=  v2(43,3);
  v2(45,1)=6;
  v2(45,2)=981;
  v2(45,3)=(-(y(12)*y(31)*params(1)*params(6)*(-((-T49)*(y(29)+y(29))))/(y(29)*y(29)*y(29)*y(29))));
  v2(46,1)=6;
  v2(46,2)=1048;
  v2(46,3)=(-(y(12)*params(1)*params(6)*T229/y(29)));
  v2(47,1)=6;
  v2(47,2)=949;
  v2(47,3)=  v2(46,3);
  v2(48,1)=6;
  v2(48,2)=1032;
  v2(48,3)=(-(params(1)*params(6)*T49/y(29)));
  v2(49,1)=6;
  v2(49,2)=405;
  v2(49,3)=  v2(48,3);
  v2(50,1)=6;
  v2(50,2)=1049;
  v2(50,3)=(-(y(12)*params(1)*params(6)*(-T49)/(y(29)*y(29))));
  v2(51,1)=6;
  v2(51,2)=983;
  v2(51,3)=  v2(50,3);
  v2(52,1)=7;
  v2(52,2)=176;
  v2(52,3)=(-(y(19)*T65*(T170*T70*T166*T166*getPowerDeriv(T72,params(8),2)+T169*T399)));
  v2(53,1)=7;
  v2(53,2)=6;
  v2(53,3)=(-(y(19)*T169*T170*T196));
  v2(54,1)=7;
  v2(54,2)=171;
  v2(54,3)=  v2(53,3);
  v2(55,1)=7;
  v2(55,2)=1;
  v2(55,3)=(-(y(19)*T76*T62*getPowerDeriv(y(1),params(10),2)));
  v2(56,1)=7;
  v2(56,2)=278;
  v2(56,3)=(-(y(19)*T65*(T208*T399+T170*T168*T207)));
  v2(57,1)=7;
  v2(57,2)=179;
  v2(57,3)=  v2(56,3);
  v2(58,1)=7;
  v2(58,2)=273;
  v2(58,3)=(-(y(19)*T196*T170*T208));
  v2(59,1)=7;
  v2(59,2)=9;
  v2(59,3)=  v2(58,3);
  v2(60,1)=7;
  v2(60,2)=281;
  v2(60,3)=(-(y(19)*T65*(T208*T208*T398+T170*T74*T205*T205*getPowerDeriv(T68,params(7),2))));
  v2(61,1)=7;
  v2(61,2)=618;
  v2(61,3)=(-(T65*T169*T170));
  v2(62,1)=7;
  v2(62,2)=189;
  v2(62,3)=  v2(61,3);
  v2(63,1)=7;
  v2(63,2)=613;
  v2(63,3)=(-(T76*T196));
  v2(64,1)=7;
  v2(64,2)=19;
  v2(64,3)=  v2(63,3);
  v2(65,1)=7;
  v2(65,2)=621;
  v2(65,3)=(-(T65*T170*T208));
  v2(66,1)=7;
  v2(66,2)=291;
  v2(66,3)=  v2(65,3);
  v2(67,1)=8;
  v2(67,2)=652;
  v2(67,3)=(-1);
  v2(68,1)=8;
  v2(68,2)=190;
  v2(68,3)=  v2(67,3);
  v2(69,1)=9;
  v2(69,2)=281;
  v2(69,3)=(-(params(6)*getPowerDeriv(y(9),params(5)-1,2)));
  v2(70,1)=9;
  v2(70,2)=386;
  v2(70,3)=(-((1-params(6))*getPowerDeriv(y(12),1-params(5),2)));
  v2(71,1)=10;
  v2(71,2)=281;
  v2(71,3)=(-(y(2)*params(6)*getPowerDeriv(y(9),params(5),2)));
  v2(72,1)=10;
  v2(72,2)=386;
  v2(72,3)=(-((1-params(6))*getPowerDeriv(y(12),(-params(5)),2)));
  v2(73,1)=10;
  v2(73,2)=43;
  v2(73,3)=(-T217);
  v2(74,1)=10;
  v2(74,2)=274;
  v2(74,3)=  v2(73,3);
  v2(75,1)=12;
  v2(75,2)=419;
  v2(75,3)=(-((-y(17))/(y(13)*y(13))));
  v2(76,1)=12;
  v2(76,2)=353;
  v2(76,3)=  v2(75,3);
  v2(77,1)=12;
  v2(77,2)=421;
  v2(77,3)=(-(y(11)*(-((-y(17))*(y(13)+y(13))))/(y(13)*y(13)*y(13)*y(13))));
  v2(78,1)=12;
  v2(78,2)=555;
  v2(78,3)=(-(1/y(13)));
  v2(79,1)=12;
  v2(79,2)=357;
  v2(79,3)=  v2(78,3);
  v2(80,1)=12;
  v2(80,2)=557;
  v2(80,3)=(-(y(11)*(-1)/(y(13)*y(13))));
  v2(81,1)=12;
  v2(81,2)=425;
  v2(81,3)=  v2(80,3);
  v2(82,1)=13;
  v2(82,2)=71;
  v2(82,3)=(-(exp(params(13)*x(it_, 1))*T111*getPowerDeriv(y(3),params(9),2)));
  v2(83,1)=13;
  v2(83,2)=1057;
  v2(83,3)=(-(T268*params(13)*exp(params(13)*x(it_, 1))));
  v2(84,1)=13;
  v2(84,2)=100;
  v2(84,3)=  v2(83,3);
  v2(85,1)=13;
  v2(85,2)=1086;
  v2(85,3)=(-(T114*params(13)*params(13)*exp(params(13)*x(it_, 1))));
  v2(86,1)=14;
  v2(86,2)=1121;
  v2(86,3)=(-((-params(14))*(-params(14))*exp((-params(14))*x(it_, 2))));
  v2(87,1)=15;
  v2(87,2)=106;
  v2(87,3)=(-(exp((-params(12))*x(it_, 3))*T130*getPowerDeriv(y(4),params(11),2)));
  v2(88,1)=15;
  v2(88,2)=1126;
  v2(88,3)=(-(T280*(-params(12))*exp((-params(12))*x(it_, 3))));
  v2(89,1)=15;
  v2(89,2)=136;
  v2(89,3)=  v2(88,3);
  v2(90,1)=15;
  v2(90,2)=1156;
  v2(90,3)=(-(T133*(-params(12))*(-params(12))*exp((-params(12))*x(it_, 3))));
  v2(91,1)=19;
  v2(91,2)=141;
  v2(91,3)=(-1)/(y(5)*y(5));
  v2(92,1)=19;
  v2(92,2)=701;
  v2(92,3)=(-((-1)/(y(21)*y(21))));
  v2(93,1)=20;
  v2(93,2)=736;
  v2(93,3)=(-((-1)/(y(22)*y(22))));
  v2(94,1)=21;
  v2(94,2)=771;
  v2(94,3)=(-((-1)/(y(23)*y(23))));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),21,1156);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],21,39304);
end
end
end
end
